<?php

namespace yiiunit\framework\widgets;

use Yii;
use yii\widgets\Menu;

/**
 * @group widgets
 */
class MenuTest extends \yiiunit\TestCase
{
    protected function setUp()
    {
        parent::setUp();
        $this->mockApplication();
    }

    public function testEncodeLabel()
    {
        $output = Menu::widget([
            'route' => 'test/test',
            'params' => [],
            'encodeLabels' => true,
            'items' => [
                [
                    'encode' => false,
                    'label'  => '<span class="glyphicon glyphicon-user"></span> Users',
                    'url'    => '#',
                ],
                [
                    'encode' => true,
                    'label'  => 'Authors & Publications',
                    'url'    => '#',
                ],
            ]
        ]);

        $expected = <<<HTML
<ul><li><a href="#"><span class="glyphicon glyphicon-user"></span> Users</a></li>
<li><a href="#">Authors &amp; Publications</a></li></ul>
HTML;
        $this->assertEqualsWithoutLE($expected, $output);

        $output = Menu::widget([
            'route' => 'test/test',
            'params' => [],
            'encodeLabels' => false,
            'items' => [
                [
                    'encode' => false,
                    'label'  => '<span class="glyphicon glyphicon-user"></span> Users',
                    'url'    => '#',
                ],
                [
                    'encode' => true,
                    'label'  => 'Authors & Publications',
                    'url'    => '#',
                ],
            ]
        ]);

        $expected = <<<HTML
<ul><li><a href="#"><span class="glyphicon glyphicon-user"></span> Users</a></li>
<li><a href="#">Authors &amp; Publications</a></li></ul>
HTML;
        $this->assertEqualsWithoutLE($expected, $output);
    }

    /**
     * @see https://github.com/yiisoft/yii2/issues/8064
     */
    public function testTagOption()
    {
        $output = Menu::widget([
            'route' => 'test/test',
            'params' => [],
            'encodeLabels' => true,
            'options' => [
                'tag' => false,
            ],
            'items' => [
                [
                    'label'  => 'item1',
                    'url'    => '#',
                    'options' => ['tag' => 'div'],
                ],
                [
                    'label'  => 'item2',
                    'url'    => '#',
                    'options' => ['tag' => false],
                ],
            ]
        ]);

        $expected = <<<HTML
<div><a href="#">item1</a></div>
<a href="#">item2</a>
HTML;
        $this->assertEqualsWithoutLE($expected, $output);

        $output = Menu::widget([
            'route' => 'test/test',
            'params' => [],
            'encodeLabels' => true,
            'options' => [
                'tag' => false,
            ],
            'items' => [
                [
                    'label'  => 'item1',
                    'url'    => '#',
                ],
                [
                    'label'  => 'item2',
                    'url'    => '#',
                ],
            ],
            'itemOptions' => ['tag' => false]
        ]);

        $expected = <<<HTML
<a href="#">item1</a>
<a href="#">item2</a>
HTML;

        $this->assertEqualsWithoutLE($expected, $output);
    }

    public function testItemTemplate()
    {
        $output = Menu::widget([
            'route' => 'test/test',
            'params' => [],
            'linkTemplate' => '',
            'labelTemplate' => '',
            'items' => [
                [
                    'label'  => 'item1',
                    'url'    => '#',
                    'template' => 'label: {label}; url: {url}'
                ],
                [
                    'label'  => 'item2',
                    'template' => 'label: {label}'
                ],
                [
                    'label'  => 'item3 (no template)',
                ],
            ]
        ]);

        $expected = <<<HTML
<ul><li>label: item1; url: #</li>
<li>label: item2</li>
<li></li></ul>
HTML;

        $this->assertEqualsWithoutLE($expected, $output);
    }

    public function testActiveItemClosure()
    {
        $output = Menu::widget([
            'route' => 'test/test',
            'params' => [],
            'linkTemplate' => '',
            'labelTemplate' => '',
            'items' => [
                [
                    'label'  => 'item1',
                    'url'    => '#',
                    'template' => 'label: {label}; url: {url}',
                    'active' => function ($item, $hasActiveChild, $isItemActive, $widget) {
                        return isset($item, $hasActiveChild, $isItemActive, $widget);
                    }
                ],
                [
                    'label'  => 'item2',
                    'template' => 'label: {label}',
                    'active' => false
                ],
                [
                    'label'  => 'item3 (no template)',
                    'active' => 'somestring'
                ],
            ]
        ]);

        $expected = <<<HTML
<ul><li class="active">label: item1; url: #</li>
<li>label: item2</li>
<li class="active"></li></ul>
HTML;

        $this->assertEqualsWithoutLE($expected, $output);
    }

    public function testIsItemActive()
    {
        // TODO: implement test of protected method isItemActive()
    }
}
